@@ -1138,8 +1138,9 @@ setMethod(f = "plot", signature = "Enrichment", definition = function (x, what =
                 tmpDF$IID <- factor(colnames(matrixER[[iType]]), levels = c("Genome", paste0("Chrom", seq(22))), labels = c("Genome", paste0("Chrom", seq(22))))
                 tmp <- reshape(tmpDF, idvar = "IID", direction = "long", varying = list(grep("R", colnames(tmpDF))), times = cnames)
                 colnames(tmp) <- c("IID", "Resampling", "Z")
+                tmp[, "Resampling"] <- as.numeric(tmp[, "Resampling"])
 
-                p <- ggplot(data = tmp, aes(x = as.numeric(Resampling), y = Z, colour = IID)) + geom_line()
+                p <- ggplot(data = tmp, aes_string(x = "Resampling", y = "Z", colour = "IID")) + geom_line()
                 noGridColour <- "transparent" # c("gray90", "grey95")
                 base_size <- 12
                 base_family <- ""
@@ -1273,7 +1274,17 @@ setMethod(f = "getEnrichSNP", signature = "Enrichment", definition = function (o
         },
         "xSNP" = {
             if (object["Call"][["readEnrichment"]][["LD"]]) {
-                object["Data"][object["Data"][, "PVALUE"]<alpha & object["Data"][, type]==1, ]
+                message('Loading ...')
+                dataSNP <- object["Data"]
+                dataLD <- object["LD"]
+                xSNP <- dataSNP[dataSNP[, "PVALUE"]<alpha & dataSNP[, type]==1, ]
+                dataLDtmp <- dataLD[dataLD %in% xSNP[, "SNP"]]
+                dataLDtmp <- cbind(SNP_A = names(dataLDtmp), SNP_B = dataLDtmp)
+                dataLDtmp <- dataLDtmp[dataLDtmp[, "SNP_A"]%in%dataSNP[dataSNP[, "eSNP"]%in%1, "SNP"], ]
+                xSNPld <- do.call("rbind",by(dataLDtmp, dataLDtmp[, "SNP_B"], function (iDta) {
+                      cbind(xSNP = unique(as.character(iDta[, "SNP_B"])), LD_with_eSNP = paste(iDta[, "SNP_A"], collapse = ";"))
+                }))
+                merge(xSNP, xSNPld, by.x = "SNP", by.y = "xSNP")
             } else {
                 warning('[Enrichment:getEnrichSNP] significant "eSNP" are returned instead of "xSNP",\n    "readEnrichment" should be run with "LD=TRUE".', call. = FALSE)
                 object["Data"][object["Data"][, "PVALUE"]<alpha & object["Data"][, type]==1, ]
